@@ -945,7 +945,6 @@ e_cal_backend_kolab_create_object (ECalBackendSync *backend,
 		}
 	}
 
-
 	ok = kolab_util_calendar_cache_assure_uid_on_ecalcomponent (priv->cal_cache,
 	                                                            priv->cal_koma,
 	                                                            ecalcomp,
@@ -962,6 +961,9 @@ e_cal_backend_kolab_create_object (ECalBackendSync *backend,
 		return;
 	}
 
+	e_cal_component_get_uid (ecalcomp, &tmp_uid);
+	*uid = g_strdup (tmp_uid);
+
 	ok = kolab_util_calendar_store (ecalcomp,
 	                                tzcomp,
 	                                priv->default_zone,
@@ -978,12 +980,23 @@ e_cal_backend_kolab_create_object (ECalBackendSync *backend,
 		return;
 	}
 
-	e_cal_component_get_uid (ecalcomp, &tmp_uid);
-	*uid = g_strdup (tmp_uid);
-	*new_component = ecalcomp;
-
+	g_object_unref (ecalcomp);
 	if (tzcomp != NULL)
 		g_object_unref (tzcomp);
+
+	/* TODO Check whether we had a collision on the server
+	 *      while storing the object (corner case, there
+	 *      would need to be a race condition between clients,
+	 *      which want to write objects with identical UID,
+	 *      between the calls to
+	 *      kolab_util_calendar_cache_assure_uid_on_ecalcomponent()
+	 *      and kolab_util_calendar_store() in this function
+	 *
+	 *      In that case we would need to read-back the object
+	 *      from the server (can UID have changed...?) and return
+	 *      a copy in *new_component (and set *uid) before returning
+	 *      from this function
+	 */
 }
 
 /**
@@ -1792,8 +1805,15 @@ e_cal_backend_kolab_start_view (ECalBackend *backend,
 			tmp_err = NULL;
 		}
 		if (ecalcomp != NULL) {
-			iCal_objects = g_slist_append (iCal_objects,
-			                               e_cal_component_get_as_string (ecalcomp));
+			gboolean do_add = FALSE;
+			gchar *compstr = NULL;
+			do_add = e_data_cal_view_component_matches (view,
+			                                            ecalcomp);
+			if (do_add) {
+				compstr = e_cal_component_get_as_string (ecalcomp);
+				iCal_objects = g_slist_append (iCal_objects,
+				                               compstr);
+			}
 			g_object_unref (ecalcomp);
 		}
 	}
