@@ -170,6 +170,8 @@ camel_kolab_imapx_metadata_init (CamelKolabImapxMetadata *kmd,
 		return FALSE;
 	}
 
+	kolab_util_folder_init ();
+
 	return TRUE;
 }
 
@@ -190,6 +192,8 @@ camel_kolab_imapx_metadata_shutdown (CamelKolabImapxMetadata *kmd,
 		return FALSE;
 	}
 
+	kolab_util_folder_shutdown ();
+
 	return TRUE;
 }
 
