@@ -304,6 +304,8 @@ extd_server_untagged (CamelIMAPXExtdServer *self,
 			CamelIMAPXStore *imapx_store = (CamelIMAPXStore *) is->store;
 			CamelIMAPXStoreNamespace *ns;
 
+			if (imapx_store->summary->namespaces)
+				camel_imapx_namespace_list_clear (imapx_store->summary->namespaces);
 			imapx_store->summary->namespaces = nsl;
 			camel_store_summary_touch ((CamelStoreSummary *) imapx_store->summary);
 
@@ -550,6 +552,8 @@ extd_server_untagged (CamelIMAPXExtdServer *self,
 
 						cnt = (camel_folder_summary_count (job->folder->summary) * 100 ) / ifolder->exists_on_server;
 						camel_operation_progress (job->cancellable, cnt ? cnt : 1);
+					} else {
+						camel_message_info_free (mi);
 					}
 
 					if (free_user_flags && server_user_flags)
