@@ -31,6 +31,7 @@
 #endif
 
 #include <string.h>
+#include <glib/gi18n-lib.h>
 
 /* Kolab error reporting */
 #include <libekolabutil/kolab-util-error.h>
@@ -507,8 +508,7 @@ camel_imapx_metadata_add_from_server_response (CamelImapxMetadata *md,
 		g_set_error (err,
 		             KOLAB_CAMEL_ERROR,
 		             KOLAB_CAMEL_ERROR_GENERIC,
-		             "%s: invalid annotation protocol",
-		             __func__);
+		             _("Invalid IMAP annotation protocol"));
 		return FALSE;
 	default:
 		/* can't happen... */
@@ -731,8 +731,7 @@ camel_imapx_metadata_spec_new (camel_imapx_metadata_proto_t proto,
 			g_set_error (err,
 			             KOLAB_CAMEL_ERROR,
 			             KOLAB_CAMEL_ERROR_GENERIC,
-			             "%s: invalid token in meta data spec",
-			             __func__);
+			             _("Invalid token in meta data string"));
 			return NULL;
 		}
 		break;
@@ -760,8 +759,7 @@ camel_imapx_metadata_spec_new (camel_imapx_metadata_proto_t proto,
 			g_set_error (err,
 			             KOLAB_CAMEL_ERROR,
 			             KOLAB_CAMEL_ERROR_GENERIC,
-			             "%s: invalid token in meta data spec",
-			             __func__);
+			             _("Invalid token in meta data string"));
 			return NULL;
 		}
 		break;
