@@ -372,8 +372,9 @@ e_kolab_account_setup_backend_create (EPlugin *epl,
 
 	g_object_set_data (G_OBJECT (epl), KOLAB_EPLUGIN_WIDGET_NAME, NULL);
 
-	if (! e_plugin_util_is_group_proto (group, KOLAB_CAMEL_PROVIDER_NAME)) {
+	if (! e_plugin_util_is_group_proto (group, KOLAB_CAMEL_PROVIDER_PROTOCOL)) {
 		/* TODO: cleanup needed */
+		g_warning ("%s()[%u] Got wrong group protocol", __func__, __LINE__);
 		return NULL;
 	}
 
