@@ -718,6 +718,9 @@ kolab_mail_imap_client_configure_store_settings (KolabMailImapClient *self,
 	CamelService *service = NULL;
 	CamelSettings *camel_settings = NULL;
 	CamelURL *camel_url = NULL;
+	CamelNetworkSecurityMethod security_method = CAMEL_NETWORK_SECURITY_METHOD_STARTTLS_ON_STANDARD_PORT;
+	guint16 port = 0;
+	KolabTLSVariantID tlsvariant = KOLAB_TLS_VARIANT_NONE;
 	GError *tmp_err = NULL;
 
 	/* TODO rework this function for new CamelSettings API
@@ -752,6 +755,54 @@ kolab_mail_imap_client_configure_store_settings (KolabMailImapClient *self,
 
 	camel_settings_load_from_url (camel_settings, camel_url);
 
+	/* get the details not (or no longer) covered by
+	 * CamelURL. Should be done for all details this
+	 * way, instead of using the (deprecated) CamelURL
+	 * for this
+	 */
+
+	/* security and port settings  */
+	tlsvariant = kolab_settings_handler_get_uint_field (priv->ksettings,
+	                                                    KOLAB_SETTINGS_HANDLER_UINT_FIELD_TLS_VARIANT,
+	                                                    &tmp_err);
+	if (tmp_err != NULL) {
+		camel_url_free (camel_url);
+		g_propagate_error (err, tmp_err);
+		return FALSE;
+	}
+
+	switch (tlsvariant) {
+	case KOLAB_TLS_VARIANT_NONE:
+		security_method = CAMEL_NETWORK_SECURITY_METHOD_NONE;
+		port = (guint16)kolab_settings_handler_get_int_field (priv->ksettings,
+		                                                      KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_IMAP_PORT,
+		                                                      &tmp_err);
+		break;
+	case KOLAB_TLS_VARIANT_SSL:
+		security_method = CAMEL_NETWORK_SECURITY_METHOD_SSL_ON_ALTERNATE_PORT;
+		port = (guint16)kolab_settings_handler_get_int_field (priv->ksettings,
+		                                                      KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_IMAPS_PORT,
+		                                                      &tmp_err);
+		break;
+	case KOLAB_TLS_VARIANT_STARTTLS:
+	default:
+		security_method = CAMEL_NETWORK_SECURITY_METHOD_STARTTLS_ON_STANDARD_PORT;
+		port = (guint16)kolab_settings_handler_get_int_field (priv->ksettings,
+		                                                      KOLAB_SETTINGS_HANDLER_INT_FIELD_KOLAB_SERVER_IMAP_PORT,
+		                                                      &tmp_err);
+	}
+	if (tmp_err != NULL) {
+		camel_url_free (camel_url);
+		g_propagate_error (err, tmp_err);
+		return FALSE;
+	}
+
+	/* set details */
+	camel_network_settings_set_security_method (CAMEL_NETWORK_SETTINGS (camel_settings),
+	                                            security_method);
+	camel_network_settings_set_port (CAMEL_NETWORK_SETTINGS (camel_settings),
+	                                 port);
+
 	/* re-set the settings for our service (store) */
 	camel_service_set_settings (service, camel_settings);
 
@@ -769,7 +820,6 @@ kolab_mail_imap_client_bringup (KolabMailImapClient *self,
 	CamelService *service = NULL;
 	gchar *dbpath = NULL;
 	gchar *account_uid = NULL;
-	gchar *extd_account_uid = NULL;
 	GError *tmp_err = NULL;
 	gboolean ok = FALSE;
 
