@@ -147,6 +147,25 @@ kolab_util_backend_get_relative_path_from_uri (const gchar *uri)
 	return path;
 } /* kolab_util_backend_get_relative_path_from_uri () */
 
+gchar*
+kolab_util_backend_get_protocol_from_uri (const gchar *uri)
+{
+	CamelURL *c_url = NULL;
+	gchar *proto = NULL;
+	GError *tmp_err = NULL;
+
+	c_url = camel_url_new (uri, &tmp_err);
+	if (c_url == NULL) {
+		g_warning ("%s()[%u] error: %s", __func__, __LINE__, tmp_err->message);
+		g_error_free (tmp_err);
+		return NULL;
+	}
+	proto = g_strdup (c_url->protocol);
+	camel_url_free (c_url);
+
+	return proto;
+}
+
 static gint
 kolab_util_misc_generic_integer_from_property (const gchar *prop_str,
                                                gint DEFAULT_VALUE)
