@@ -134,7 +134,8 @@ create_evolution_vcard_tested (const ECalComponentWithTZ* epim, gint *stage)
 		icalcomponent_add_component (ical_vcal, ical_vtz);
 	}
 	icalcomponent_add_component (ical_vcal, ical_vevent);
-	ical_str = icalcomponent_as_ical_string (ical_vcal);
+	/* memory returned by *_as_ical_string() is owned by libical */
+	ical_str = g_strdup (icalcomponent_as_ical_string (ical_vcal));
 	/* free allocated resources */
 	if (ical_vtz != NULL)
 		icalcomponent_remove_component(ical_vcal, ical_vtz);
