@@ -29,7 +29,7 @@
 
 #include <glib/gi18n-lib.h>
 
-#include <e-util/e-util.h>
+#include <libedataserver/e-data-server-util.h>
 
 #include "camel-system-headers.h"
 #include "kolab-util-error.h"
@@ -55,8 +55,8 @@ kolab_util_camel_init (GError **err)
 	/* init Camel subsystem */
 	if (camel_init (e_get_user_data_dir (), TRUE) != 0) {
 		g_set_error (err,
-			     KOLAB_CAMEL_ERROR,
-			     KOLAB_CAMEL_ERROR_GENERIC,
+		             KOLAB_CAMEL_ERROR,
+		             KOLAB_CAMEL_ERROR_GENERIC,
 		             _("Failed to initialize Camel subsystem"));
 		return FALSE;
 	}
@@ -87,50 +87,20 @@ kolab_util_camel_get_storage_path (CamelService *service,
                                    GError **err)
 {
 	gchar *store_path = NULL;
-	CamelURL *url = NULL;
 
 	g_assert (CAMEL_IS_SERVICE (service));
 	g_assert (CAMEL_IS_SESSION (session));
 	g_return_val_if_fail (err == NULL || *err == NULL, NULL);
 
-	/* FIXME Rework the whole CamelURL / CamelSettings / CamelService
-	 *	 stuff according to mbarnes' changes
-	 */
-	url = camel_service_new_camel_url (service);
-	g_assert (url != NULL);
-	g_assert (url->path != NULL);
-	store_path = g_strdup (url->path);
-	camel_url_free (url);
+	store_path = g_strdup (camel_service_get_user_cache_dir (service));
 
-#if 0
-	if (service->url->path != NULL)
-		return g_strdup (service->url->path);
-
-	store_path = camel_session_get_storage_path (session,
-	                                             service,
-	                                             &tmp_err);
-	if (tmp_err != NULL) {
-		g_warning ("%s: %s",
-		           __func__,
-		           tmp_err->message);
-		g_error_free (tmp_err);
-		tmp_err = NULL;
-		if (store_path != NULL) {
-			g_free (store_path);
-			store_path = NULL;
-		}
-	}
-	if (store_path == NULL)
-		store_path = camel_session_get_storage_path (session,
-		                                             service,
-		                                             NULL);
 	if (store_path == NULL) {
+		/* FIXME mark this as a translatable string */
 		g_set_error (err,
-			     KOLAB_CAMEL_KOLAB_ERROR,
-			     KOLAB_CAMEL_KOLAB_ERROR_DB,
-		             _("Could not get Camel storage path"));
+		             KOLAB_CAMEL_KOLAB_ERROR,
+		             KOLAB_CAMEL_KOLAB_ERROR_DB,
+		             "Could not get Camel storage path");
 	}
-#endif
 
 	return store_path;
 }
